@@ -83,4 +83,7 @@ DEFINITION = {
     'amqp_kombu':[
         ('kombu','instrument_kombu'),
     ],
+    'amqp_pika':[
+        ('pika.channel','instrument_pika'),
+    ],
 }
